# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
from google.rpc import status_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.video.live_stream_v1.types import outputs

__protobuf__ = proto.module(
    package="google.cloud.video.livestream.v1",
    manifest={
        "Input",
        "Channel",
        "NormalizedCoordinate",
        "NormalizedResolution",
        "StaticOverlay",
        "InputConfig",
        "LogConfig",
        "RetentionConfig",
        "InputStreamProperty",
        "VideoStreamProperty",
        "VideoFormat",
        "AudioStreamProperty",
        "AudioFormat",
        "InputAttachment",
        "Event",
        "Clip",
        "Asset",
        "Encryption",
        "Pool",
    },
)


class Input(proto.Message):
    r"""Input resource represents the endpoint from which the channel
    ingests the input stream.

    Attributes:
        name (str):
            The resource name of the input, in the form of:
            ``projects/{project}/locations/{location}/inputs/{inputId}``.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The creation time.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The update time.
        labels (MutableMapping[str, str]):
            User-defined key/value metadata.
        type_ (google.cloud.video.live_stream_v1.types.Input.Type):
            Source type.
        tier (google.cloud.video.live_stream_v1.types.Input.Tier):
            Tier defines the maximum input specification that is
            accepted by the video pipeline. The billing is charged based
            on the tier specified here. See
            `Pricing <https://cloud.google.com/livestream/pricing>`__
            for more detail. The default is ``HD``.
        uri (str):
            Output only. URI to push the input stream to. Its format
            depends on the input
            [type][google.cloud.video.livestream.v1.Input.type], for
            example:

            -  ``RTMP_PUSH``: ``rtmp://1.2.3.4/live/{STREAM-ID}``
            -  ``SRT_PUSH``: ``srt://1.2.3.4:4201?streamid={STREAM-ID}``
        preprocessing_config (google.cloud.video.live_stream_v1.types.PreprocessingConfig):
            Preprocessing configurations.
        security_rules (google.cloud.video.live_stream_v1.types.Input.SecurityRule):
            Security rule for access control.
        input_stream_property (google.cloud.video.live_stream_v1.types.InputStreamProperty):
            Output only. The information for the input
            stream. This field will be present only when
            this input receives the input stream.
    """

    class Type(proto.Enum):
        r"""The type of the input.

        Values:
            TYPE_UNSPECIFIED (0):
                Input type is not specified.
            RTMP_PUSH (1):
                Input will take an rtmp input stream.
            SRT_PUSH (2):
                Input will take an srt (Secure Reliable
                Transport) input stream.
        """
        TYPE_UNSPECIFIED = 0
        RTMP_PUSH = 1
        SRT_PUSH = 2

    class Tier(proto.Enum):
        r"""Tier of the input specification.

        Values:
            TIER_UNSPECIFIED (0):
                Tier is not specified.
            SD (1):
                Resolution < 1280x720. Bitrate <= 6 Mbps. FPS
                <= 60.
            HD (2):
                Resolution <= 1920x1080. Bitrate <= 25 Mbps.
                FPS <= 60.
            UHD (3):
                Resolution <= 4096x2160. Not supported yet.
        """
        TIER_UNSPECIFIED = 0
        SD = 1
        HD = 2
        UHD = 3

    class SecurityRule(proto.Message):
        r"""Security rules for access control. Each field represents one
        security rule. Only when the source of the input stream
        satisfies all the fields, this input stream can be accepted.

        Attributes:
            ip_ranges (MutableSequence[str]):
                At least one ip range must match unless none specified. The
                IP range is defined by CIDR block: for example,
                ``192.0.1.0/24`` for a range and ``192.0.1.0/32`` for a
                single IP address.
        """

        ip_ranges: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=1,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    type_: Type = proto.Field(
        proto.ENUM,
        number=5,
        enum=Type,
    )
    tier: Tier = proto.Field(
        proto.ENUM,
        number=14,
        enum=Tier,
    )
    uri: str = proto.Field(
        proto.STRING,
        number=6,
    )
    preprocessing_config: outputs.PreprocessingConfig = proto.Field(
        proto.MESSAGE,
        number=9,
        message=outputs.PreprocessingConfig,
    )
    security_rules: SecurityRule = proto.Field(
        proto.MESSAGE,
        number=12,
        message=SecurityRule,
    )
    input_stream_property: "InputStreamProperty" = proto.Field(
        proto.MESSAGE,
        number=15,
        message="InputStreamProperty",
    )


class Channel(proto.Message):
    r"""Channel resource represents the processor that does a
    user-defined "streaming" operation, which includes getting an
    input stream through an input, transcoding it to multiple
    renditions, and publishing output live streams in certain
    formats (for example, HLS or DASH) to the specified location.

    Attributes:
        name (str):
            The resource name of the channel, in the form of:
            ``projects/{project}/locations/{location}/channels/{channelId}``.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The creation time.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The update time.
        labels (MutableMapping[str, str]):
            User-defined key/value metadata.
        input_attachments (MutableSequence[google.cloud.video.live_stream_v1.types.InputAttachment]):
            A list of input attachments that this channel
            uses. One channel can have multiple inputs as
            the input sources. Only one input can be
            selected as the input source at one time.
        active_input (str):
            Output only. The
            [InputAttachment.key][google.cloud.video.livestream.v1.InputAttachment.key]
            that serves as the current input source. The first input in
            the
            [input_attachments][google.cloud.video.livestream.v1.Channel.input_attachments]
            is the initial input source.
        output (google.cloud.video.live_stream_v1.types.Channel.Output):
            Required. Information about the output (that
            is, the Cloud Storage bucket to store the
            generated live stream).
        elementary_streams (MutableSequence[google.cloud.video.live_stream_v1.types.ElementaryStream]):
            List of elementary streams.
        mux_streams (MutableSequence[google.cloud.video.live_stream_v1.types.MuxStream]):
            List of multiplexing settings for output
            streams.
        manifests (MutableSequence[google.cloud.video.live_stream_v1.types.Manifest]):
            List of output manifests.
        sprite_sheets (MutableSequence[google.cloud.video.live_stream_v1.types.SpriteSheet]):
            List of output sprite sheets.
        streaming_state (google.cloud.video.live_stream_v1.types.Channel.StreamingState):
            Output only. State of the streaming
            operation.
        streaming_error (google.rpc.status_pb2.Status):
            Output only. A description of the reason for the streaming
            error. This property is always present when
            [streaming_state][google.cloud.video.livestream.v1.Channel.streaming_state]
            is
            [STREAMING_ERROR][google.cloud.video.livestream.v1.Channel.StreamingState.STREAMING_ERROR].
        log_config (google.cloud.video.live_stream_v1.types.LogConfig):
            Configuration of platform logs for this
            channel.
        timecode_config (google.cloud.video.live_stream_v1.types.TimecodeConfig):
            Configuration of timecode for this channel.
        encryptions (MutableSequence[google.cloud.video.live_stream_v1.types.Encryption]):
            Encryption configurations for this channel.
            Each configuration has an ID which is referred
            to by each MuxStream to indicate which
            configuration is used for that output.
        input_config (google.cloud.video.live_stream_v1.types.InputConfig):
            The configuration for input sources defined in
            [input_attachments][google.cloud.video.livestream.v1.Channel.input_attachments].
        retention_config (google.cloud.video.live_stream_v1.types.RetentionConfig):
            Optional. Configuration for retention of
            output files for this channel.
        static_overlays (MutableSequence[google.cloud.video.live_stream_v1.types.StaticOverlay]):
            Optional. List of static overlay images.
            Those images display over the output content for
            the whole duration of the live stream.
    """

    class StreamingState(proto.Enum):
        r"""State of streaming operation that the channel is running.

        Values:
            STREAMING_STATE_UNSPECIFIED (0):
                Streaming state is not specified.
            STREAMING (1):
                Channel is getting the input stream,
                generating the live streams to the specified
                output location.
            AWAITING_INPUT (2):
                Channel is waiting for the input stream
                through the input.
            STREAMING_ERROR (4):
                Channel is running, but has trouble
                publishing the live streams onto the specified
                output location (for example, the specified
                Cloud Storage bucket is not writable).
            STREAMING_NO_INPUT (5):
                Channel is generating live streams with no
                input stream. Live streams are filled out with
                black screen, while input stream is missing. Not
                supported yet.
            STOPPED (6):
                Channel is stopped, finishing live streams.
            STARTING (7):
                Channel is starting.
            STOPPING (8):
                Channel is stopping.
        """
        STREAMING_STATE_UNSPECIFIED = 0
        STREAMING = 1
        AWAITING_INPUT = 2
        STREAMING_ERROR = 4
        STREAMING_NO_INPUT = 5
        STOPPED = 6
        STARTING = 7
        STOPPING = 8

    class Output(proto.Message):
        r"""Location of output file(s) in a Google Cloud Storage bucket.

        Attributes:
            uri (str):
                URI for the output file(s). For example,
                ``gs://my-bucket/outputs/``.
        """

        uri: str = proto.Field(
            proto.STRING,
            number=1,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    input_attachments: MutableSequence["InputAttachment"] = proto.RepeatedField(
        proto.MESSAGE,
        number=16,
        message="InputAttachment",
    )
    active_input: str = proto.Field(
        proto.STRING,
        number=6,
    )
    output: Output = proto.Field(
        proto.MESSAGE,
        number=9,
        message=Output,
    )
    elementary_streams: MutableSequence[outputs.ElementaryStream] = proto.RepeatedField(
        proto.MESSAGE,
        number=10,
        message=outputs.ElementaryStream,
    )
    mux_streams: MutableSequence[outputs.MuxStream] = proto.RepeatedField(
        proto.MESSAGE,
        number=11,
        message=outputs.MuxStream,
    )
    manifests: MutableSequence[outputs.Manifest] = proto.RepeatedField(
        proto.MESSAGE,
        number=12,
        message=outputs.Manifest,
    )
    sprite_sheets: MutableSequence[outputs.SpriteSheet] = proto.RepeatedField(
        proto.MESSAGE,
        number=13,
        message=outputs.SpriteSheet,
    )
    streaming_state: StreamingState = proto.Field(
        proto.ENUM,
        number=14,
        enum=StreamingState,
    )
    streaming_error: status_pb2.Status = proto.Field(
        proto.MESSAGE,
        number=18,
        message=status_pb2.Status,
    )
    log_config: "LogConfig" = proto.Field(
        proto.MESSAGE,
        number=19,
        message="LogConfig",
    )
    timecode_config: outputs.TimecodeConfig = proto.Field(
        proto.MESSAGE,
        number=21,
        message=outputs.TimecodeConfig,
    )
    encryptions: MutableSequence["Encryption"] = proto.RepeatedField(
        proto.MESSAGE,
        number=24,
        message="Encryption",
    )
    input_config: "InputConfig" = proto.Field(
        proto.MESSAGE,
        number=25,
        message="InputConfig",
    )
    retention_config: "RetentionConfig" = proto.Field(
        proto.MESSAGE,
        number=26,
        message="RetentionConfig",
    )
    static_overlays: MutableSequence["StaticOverlay"] = proto.RepeatedField(
        proto.MESSAGE,
        number=27,
        message="StaticOverlay",
    )


class NormalizedCoordinate(proto.Message):
    r"""2D normalized coordinates.

    Attributes:
        x (float):
            Optional. Normalized x coordinate. Valid range is [0.0,
            1.0]. Default is 0.
        y (float):
            Optional. Normalized y coordinate. Valid range is [0.0,
            1.0]. Default is 0.
    """

    x: float = proto.Field(
        proto.DOUBLE,
        number=1,
    )
    y: float = proto.Field(
        proto.DOUBLE,
        number=2,
    )


class NormalizedResolution(proto.Message):
    r"""Normalized resolution.

    Attributes:
        w (float):
            Optional. Normalized width. Valid range is [0.0, 1.0].
            Default is 0.
        h (float):
            Optional. Normalized height. Valid range is [0.0, 1.0].
            Default is 0.
    """

    w: float = proto.Field(
        proto.DOUBLE,
        number=1,
    )
    h: float = proto.Field(
        proto.DOUBLE,
        number=2,
    )


class StaticOverlay(proto.Message):
    r"""Configuration for the static overlay.

    Attributes:
        asset (str):
            Required. Asset to use for the overlaid image. The asset
            must be represented in the form of:
            ``projects/{project}/locations/{location}/assets/{assetId}``.
            The asset's resource type must be image.
        resolution (google.cloud.video.live_stream_v1.types.NormalizedResolution):
            Optional. Normalized image resolution, based on output video
            resolution. Valid values are [0.0, 1.0]. To respect the
            original image aspect ratio, set either ``w`` or ``h`` to 0.
            To use the original image resolution, set both ``w`` and
            ``h`` to 0. The default is {0, 0}.
        position (google.cloud.video.live_stream_v1.types.NormalizedCoordinate):
            Optional. Position of the image in terms of
            normalized coordinates of the upper-left corner
            of the image, based on output video resolution.
            For example, use the x and y coordinates {0, 0}
            to position the top-left corner of the overlay
            animation in the top-left corner of the output
            video.
        opacity (float):
            Optional. Target image opacity. Valid values are from
            ``1.0`` (solid, default) to ``0.0`` (transparent),
            exclusive. Set this to a value greater than ``0.0``.
    """

    asset: str = proto.Field(
        proto.STRING,
        number=1,
    )
    resolution: "NormalizedResolution" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="NormalizedResolution",
    )
    position: "NormalizedCoordinate" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="NormalizedCoordinate",
    )
    opacity: float = proto.Field(
        proto.DOUBLE,
        number=4,
    )


class InputConfig(proto.Message):
    r"""Configuration for the input sources of a channel.

    Attributes:
        input_switch_mode (google.cloud.video.live_stream_v1.types.InputConfig.InputSwitchMode):
            Input switch mode. Default mode is
            ``FAILOVER_PREFER_PRIMARY``.
    """

    class InputSwitchMode(proto.Enum):
        r"""Input switch mode.

        Values:
            INPUT_SWITCH_MODE_UNSPECIFIED (0):
                The input switch mode is not specified.
            FAILOVER_PREFER_PRIMARY (1):
                Automatic failover is enabled. The primary input stream is
                always preferred over its backup input streams configured
                using the
                [AutomaticFailover][google.cloud.video.livestream.v1.InputAttachment.AutomaticFailover]
                field.
            MANUAL (3):
                Automatic failover is disabled. You must use the
                [inputSwitch][google.cloud.video.livestream.v1.Event.input_switch]
                event to switch the active input source for the channel to
                stream from. When this mode is chosen, the
                [AutomaticFailover][google.cloud.video.livestream.v1.InputAttachment.AutomaticFailover]
                field is ignored.
        """
        INPUT_SWITCH_MODE_UNSPECIFIED = 0
        FAILOVER_PREFER_PRIMARY = 1
        MANUAL = 3

    input_switch_mode: InputSwitchMode = proto.Field(
        proto.ENUM,
        number=1,
        enum=InputSwitchMode,
    )


class LogConfig(proto.Message):
    r"""Configuration of platform logs. See `Using and managing platform
    logs <https://cloud.google.com/logging/docs/api/platform-logs#managing-logs>`__
    for more information about how to view platform logs through Cloud
    Logging.

    Attributes:
        log_severity (google.cloud.video.live_stream_v1.types.LogConfig.LogSeverity):
            The severity level of platform logging for
            this resource.
    """

    class LogSeverity(proto.Enum):
        r"""The severity level of platform logging for this channel. Logs with a
        severity level higher than or equal to the chosen severity level
        will be logged and can be viewed through Cloud Logging. The severity
        level of a log is ranked as followed from low to high: DEBUG < INFO
        < NOTICE < WARNING < ERROR < CRITICAL < ALERT < EMERGENCY. See
        `LogSeverity <https://cloud.google.com/logging/docs/reference/v2/rest/v2/LogEntry#logseverity>`__
        for more information.

        Values:
            LOG_SEVERITY_UNSPECIFIED (0):
                Log severity is not specified. This is the
                same as log severity is OFF.
            OFF (1):
                Log is turned off.
            DEBUG (100):
                Log with severity higher than or equal to
                DEBUG are logged.
            INFO (200):
                Logs with severity higher than or equal to
                INFO are logged.
            WARNING (400):
                Logs with severity higher than or equal to
                WARNING are logged.
            ERROR (500):
                Logs with severity higher than or equal to
                ERROR are logged.
        """
        LOG_SEVERITY_UNSPECIFIED = 0
        OFF = 1
        DEBUG = 100
        INFO = 200
        WARNING = 400
        ERROR = 500

    log_severity: LogSeverity = proto.Field(
        proto.ENUM,
        number=1,
        enum=LogSeverity,
    )


class RetentionConfig(proto.Message):
    r"""Configuration for retention of output files.

    Attributes:
        retention_window_duration (google.protobuf.duration_pb2.Duration):
            The minimum duration for which the output files from the
            channel will remain in the output bucket. After this
            duration, output files are deleted asynchronously.

            When the channel is deleted, all output files are deleted
            from the output bucket asynchronously.

            If omitted or set to zero, output files will remain in the
            output bucket based on
            [Manifest.segment_keep_duration][google.cloud.video.livestream.v1.Manifest.segment_keep_duration],
            which defaults to 60s.

            If both retention_window_duration and
            [Manifest.segment_keep_duration][google.cloud.video.livestream.v1.Manifest.segment_keep_duration]
            are set, retention_window_duration is used and
            [Manifest.segment_keep_duration][google.cloud.video.livestream.v1.Manifest.segment_keep_duration]
            is ignored.
    """

    retention_window_duration: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=1,
        message=duration_pb2.Duration,
    )


class InputStreamProperty(proto.Message):
    r"""Properties of the input stream.

    Attributes:
        last_establish_time (google.protobuf.timestamp_pb2.Timestamp):
            The time that the current input stream is
            accepted and the connection is established.
        video_streams (MutableSequence[google.cloud.video.live_stream_v1.types.VideoStreamProperty]):
            Properties of the video streams.
        audio_streams (MutableSequence[google.cloud.video.live_stream_v1.types.AudioStreamProperty]):
            Properties of the audio streams.
    """

    last_establish_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    video_streams: MutableSequence["VideoStreamProperty"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="VideoStreamProperty",
    )
    audio_streams: MutableSequence["AudioStreamProperty"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="AudioStreamProperty",
    )


class VideoStreamProperty(proto.Message):
    r"""Properties of the video stream.

    Attributes:
        index (int):
            Index of this video stream.
        video_format (google.cloud.video.live_stream_v1.types.VideoFormat):
            Properties of the video format.
    """

    index: int = proto.Field(
        proto.INT32,
        number=1,
    )
    video_format: "VideoFormat" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="VideoFormat",
    )


class VideoFormat(proto.Message):
    r"""Properties of the video format.

    Attributes:
        codec (str):
            Video codec used in this video stream.
        width_pixels (int):
            The width of the video stream in pixels.
        height_pixels (int):
            The height of the video stream in pixels.
        frame_rate (float):
            The frame rate of the input video stream.
    """

    codec: str = proto.Field(
        proto.STRING,
        number=1,
    )
    width_pixels: int = proto.Field(
        proto.INT32,
        number=2,
    )
    height_pixels: int = proto.Field(
        proto.INT32,
        number=3,
    )
    frame_rate: float = proto.Field(
        proto.DOUBLE,
        number=4,
    )


class AudioStreamProperty(proto.Message):
    r"""Properties of the audio stream.

    Attributes:
        index (int):
            Index of this audio stream.
        audio_format (google.cloud.video.live_stream_v1.types.AudioFormat):
            Properties of the audio format.
    """

    index: int = proto.Field(
        proto.INT32,
        number=1,
    )
    audio_format: "AudioFormat" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="AudioFormat",
    )


class AudioFormat(proto.Message):
    r"""Properties of the audio format.

    Attributes:
        codec (str):
            Audio codec used in this audio stream.
        channel_count (int):
            The number of audio channels.
        channel_layout (MutableSequence[str]):
            A list of channel names specifying the layout
            of the audio channels.
    """

    codec: str = proto.Field(
        proto.STRING,
        number=1,
    )
    channel_count: int = proto.Field(
        proto.INT32,
        number=2,
    )
    channel_layout: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class InputAttachment(proto.Message):
    r"""A group of information for attaching an input resource to
    this channel.

    Attributes:
        key (str):
            A unique key for this input attachment. The
            key must be 1-63 characters in length. The key
            must begin and end with a letter (regardless of
            case) or a number, but can contain dashes or
            underscores in between.
        input (str):
            The resource name of an existing input, in the form of:
            ``projects/{project}/locations/{location}/inputs/{inputId}``.
        automatic_failover (google.cloud.video.live_stream_v1.types.InputAttachment.AutomaticFailover):
            Automatic failover configurations.
    """

    class AutomaticFailover(proto.Message):
        r"""Configurations to follow when automatic failover happens.

        Attributes:
            input_keys (MutableSequence[str]):
                The
                [InputAttachment.key][google.cloud.video.livestream.v1.InputAttachment.key]s
                of inputs to failover to when this input is disconnected.
                Currently, only up to one backup input is supported.
        """

        input_keys: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=1,
        )

    key: str = proto.Field(
        proto.STRING,
        number=1,
    )
    input: str = proto.Field(
        proto.STRING,
        number=2,
    )
    automatic_failover: AutomaticFailover = proto.Field(
        proto.MESSAGE,
        number=3,
        message=AutomaticFailover,
    )


class Event(proto.Message):
    r"""Event is a sub-resource of a channel, which can be scheduled
    by the user to execute operations on a channel resource without
    having to stop the channel.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            The resource name of the event, in the form of:
            ``projects/{project}/locations/{location}/channels/{channelId}/events/{eventId}``.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The creation time.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The update time.
        labels (MutableMapping[str, str]):
            User-defined key/value metadata.
        input_switch (google.cloud.video.live_stream_v1.types.Event.InputSwitchTask):
            Switches to another input stream.

            This field is a member of `oneof`_ ``task``.
        ad_break (google.cloud.video.live_stream_v1.types.Event.AdBreakTask):
            Inserts a new ad opportunity.

            This field is a member of `oneof`_ ``task``.
        return_to_program (google.cloud.video.live_stream_v1.types.Event.ReturnToProgramTask):
            Stops any running ad break.

            This field is a member of `oneof`_ ``task``.
        slate (google.cloud.video.live_stream_v1.types.Event.SlateTask):
            Inserts a slate.

            This field is a member of `oneof`_ ``task``.
        mute (google.cloud.video.live_stream_v1.types.Event.MuteTask):
            Mutes the stream.

            This field is a member of `oneof`_ ``task``.
        unmute (google.cloud.video.live_stream_v1.types.Event.UnmuteTask):
            Unmutes the stream.

            This field is a member of `oneof`_ ``task``.
        execute_now (bool):
            When this field is set to true, the event will be executed
            at the earliest time that the server can schedule the event
            and
            [execution_time][google.cloud.video.livestream.v1.Event.execution_time]
            will be populated with the time that the server actually
            schedules the event.
        execution_time (google.protobuf.timestamp_pb2.Timestamp):
            The time to execute the event. If you set
            [execute_now][google.cloud.video.livestream.v1.Event.execute_now]
            to ``true``, then do not set this field in the
            ``CreateEvent`` request. In this case, the server schedules
            the event and populates this field. If you set
            [execute_now][google.cloud.video.livestream.v1.Event.execute_now]
            to ``false``, then you must set this field to at least 10
            seconds in the future or else the event can't be created.
        state (google.cloud.video.live_stream_v1.types.Event.State):
            Output only. The state of the event.
        error (google.rpc.status_pb2.Status):
            Output only. An error object that describes the reason for
            the failure. This property is always present when ``state``
            is ``FAILED``.
    """

    class State(proto.Enum):
        r"""State of the event

        Values:
            STATE_UNSPECIFIED (0):
                Event state is not specified.
            SCHEDULED (1):
                Event is scheduled but not executed yet.
            RUNNING (2):
                Event is being executed.
            SUCCEEDED (3):
                Event has been successfully executed.
            FAILED (4):
                Event fails to be executed.
            PENDING (5):
                Event has been created but not scheduled yet.
            STOPPED (6):
                Event was stopped before running for its full
                duration.
        """
        STATE_UNSPECIFIED = 0
        SCHEDULED = 1
        RUNNING = 2
        SUCCEEDED = 3
        FAILED = 4
        PENDING = 5
        STOPPED = 6

    class InputSwitchTask(proto.Message):
        r"""Switches to another input stream. Automatic failover is then
        disabled.

        Attributes:
            input_key (str):
                The
                [InputAttachment.key][google.cloud.video.livestream.v1.InputAttachment.key]
                of the input to switch to.
        """

        input_key: str = proto.Field(
            proto.STRING,
            number=1,
        )

    class AdBreakTask(proto.Message):
        r"""Inserts a new ad opportunity.

        Attributes:
            duration (google.protobuf.duration_pb2.Duration):
                Duration of an ad opportunity. Must be
                greater than 0.
        """

        duration: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=1,
            message=duration_pb2.Duration,
        )

    class SlateTask(proto.Message):
        r"""Inserts a slate.

        Attributes:
            duration (google.protobuf.duration_pb2.Duration):
                Optional. Duration of the slate. Must be
                greater than 0 if specified. Omit this field for
                a long running slate.
            asset (str):
                Slate asset to use for the duration. If its duration is less
                than the duration of the SlateTask, then the slate loops.
                The slate must be represented in the form of:
                ``projects/{project}/locations/{location}/assets/{assetId}``.
        """

        duration: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=1,
            message=duration_pb2.Duration,
        )
        asset: str = proto.Field(
            proto.STRING,
            number=2,
        )

    class ReturnToProgramTask(proto.Message):
        r"""Stops any events which are currently running. This only
        applies to events with a duration.

        """

    class MuteTask(proto.Message):
        r"""Mutes the stream.

        Attributes:
            duration (google.protobuf.duration_pb2.Duration):
                Duration for which the stream should be
                muted. If omitted, the stream will be muted
                until an UnmuteTask event is sent.
        """

        duration: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=1,
            message=duration_pb2.Duration,
        )

    class UnmuteTask(proto.Message):
        r"""Unmutes the stream. The task fails if the stream is not
        currently muted.

        """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    input_switch: InputSwitchTask = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="task",
        message=InputSwitchTask,
    )
    ad_break: AdBreakTask = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="task",
        message=AdBreakTask,
    )
    return_to_program: ReturnToProgramTask = proto.Field(
        proto.MESSAGE,
        number=13,
        oneof="task",
        message=ReturnToProgramTask,
    )
    slate: SlateTask = proto.Field(
        proto.MESSAGE,
        number=14,
        oneof="task",
        message=SlateTask,
    )
    mute: MuteTask = proto.Field(
        proto.MESSAGE,
        number=15,
        oneof="task",
        message=MuteTask,
    )
    unmute: UnmuteTask = proto.Field(
        proto.MESSAGE,
        number=16,
        oneof="task",
        message=UnmuteTask,
    )
    execute_now: bool = proto.Field(
        proto.BOOL,
        number=9,
    )
    execution_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=10,
        message=timestamp_pb2.Timestamp,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=11,
        enum=State,
    )
    error: status_pb2.Status = proto.Field(
        proto.MESSAGE,
        number=12,
        message=status_pb2.Status,
    )


class Clip(proto.Message):
    r"""Clip is a sub-resource under channel. Each clip represents a
    clipping operation that generates a VOD playlist from its
    channel given a set of timestamp ranges.

    Attributes:
        name (str):
            The resource name of the clip, in the following format:
            ``projects/{project}/locations/{location}/channels/{c}/clips/{clipId}``.
            ``{clipId}`` is a user-specified resource id that conforms
            to the following criteria:

            1. 1 character minimum, 63 characters maximum
            2. Only contains letters, digits, underscores, and hyphens
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The creation timestamp of the
            clip resource.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The timestamp when the clip
            request starts to be processed.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The update timestamp of the clip
            resource.
        labels (MutableMapping[str, str]):
            The labels associated with this resource.
            Each label is a key-value pair.
        state (google.cloud.video.live_stream_v1.types.Clip.State):
            Output only. The state of the clip.
        output_uri (str):
            Specify the ``output_uri`` to determine where to place the
            clip segments and clip manifest files in Cloud Storage. The
            manifests specified in ``clip_manifests`` fields will be
            placed under this URI. The exact URI of the generated
            manifests will be provided in ``clip_manifests.output_uri``
            for each manifest. Example: "output_uri":
            "gs://my-bucket/clip-outputs" "clip_manifests.output_uri":
            "gs://my-bucket/clip-outputs/main.m3u8".
        error (google.rpc.status_pb2.Status):
            Output only. An error object that describes the reason for
            the failure. This property only presents when ``state`` is
            ``FAILED``.
        slices (MutableSequence[google.cloud.video.live_stream_v1.types.Clip.Slice]):
            The specified ranges of segments to generate
            a clip.
        clip_manifests (MutableSequence[google.cloud.video.live_stream_v1.types.Clip.ClipManifest]):
            Required. A list of clip manifests. Currently
            only one clip manifest is allowed.
    """

    class State(proto.Enum):
        r"""State of clipping operation.

        Values:
            STATE_UNSPECIFIED (0):
                State is not specified.
            PENDING (1):
                The operation is pending to be picked up by
                the server.
            CREATING (2):
                The server admitted this create clip request,
                and outputs are under processing.
            SUCCEEDED (3):
                Outputs are available in the specified Cloud Storage bucket.
                For additional information, see the ``outputs`` field.
            FAILED (4):
                The operation has failed. For additional information, see
                the ``error`` field.
        """
        STATE_UNSPECIFIED = 0
        PENDING = 1
        CREATING = 2
        SUCCEEDED = 3
        FAILED = 4

    class TimeSlice(proto.Message):
        r"""TimeSlice represents a tuple of Unix epoch timestamps that
        specifies a time range.

        Attributes:
            markin_time (google.protobuf.timestamp_pb2.Timestamp):
                The mark-in Unix epoch time in the original
                live stream manifest.
            markout_time (google.protobuf.timestamp_pb2.Timestamp):
                The mark-out Unix epoch time in the original
                live stream manifest.
        """

        markin_time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=1,
            message=timestamp_pb2.Timestamp,
        )
        markout_time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=2,
            message=timestamp_pb2.Timestamp,
        )

    class Slice(proto.Message):
        r"""Slice represents a slice of the requested clip.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            time_slice (google.cloud.video.live_stream_v1.types.Clip.TimeSlice):
                A slice in form of a tuple of Unix epoch
                time.

                This field is a member of `oneof`_ ``kind``.
        """

        time_slice: "Clip.TimeSlice" = proto.Field(
            proto.MESSAGE,
            number=1,
            oneof="kind",
            message="Clip.TimeSlice",
        )

    class ClipManifest(proto.Message):
        r"""ClipManifest identifies a source manifest for the generated
        clip manifest.

        Attributes:
            manifest_key (str):
                Required. A unique key that identifies a manifest config in
                the parent channel. This key is the same as
                ``channel.manifests.key`` for the selected manifest.
            output_uri (str):
                Output only. The output URI of the generated clip manifest.
                This field will be populated when the CreateClip request is
                accepted. Current output format is provided below but may
                change in the future. Please read this field to get the uri
                to the generated clip manifest. Format:
                {clip.output_uri}/{channel.manifest.fileName} Example:
                gs://my-bucket/clip-outputs/main.m3u8
        """

        manifest_key: str = proto.Field(
            proto.STRING,
            number=1,
        )
        output_uri: str = proto.Field(
            proto.STRING,
            number=2,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=5,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=6,
        enum=State,
    )
    output_uri: str = proto.Field(
        proto.STRING,
        number=7,
    )
    error: status_pb2.Status = proto.Field(
        proto.MESSAGE,
        number=9,
        message=status_pb2.Status,
    )
    slices: MutableSequence[Slice] = proto.RepeatedField(
        proto.MESSAGE,
        number=10,
        message=Slice,
    )
    clip_manifests: MutableSequence[ClipManifest] = proto.RepeatedField(
        proto.MESSAGE,
        number=12,
        message=ClipManifest,
    )


class Asset(proto.Message):
    r"""An asset represents a video or an image.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            The resource name of the asset, in the form of:
            ``projects/{project}/locations/{location}/assets/{assetId}``.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The creation time.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The update time.
        labels (MutableMapping[str, str]):
            User-defined key/value metadata.
        video (google.cloud.video.live_stream_v1.types.Asset.VideoAsset):
            VideoAsset represents a video.

            This field is a member of `oneof`_ ``resource``.
        image (google.cloud.video.live_stream_v1.types.Asset.ImageAsset):
            ImageAsset represents an image.

            This field is a member of `oneof`_ ``resource``.
        crc32c (str):
            Based64-encoded CRC32c checksum of the asset file. For more
            information, see the crc32c checksum of the `Cloud Storage
            Objects
            resource <https://cloud.google.com/storage/docs/json_api/v1/objects>`__.
            If crc32c is omitted or left empty when the asset is
            created, this field is filled by the crc32c checksum of the
            Cloud Storage object indicated by
            [VideoAsset.uri][google.cloud.video.livestream.v1.Asset.VideoAsset.uri]
            or
            [ImageAsset.uri][google.cloud.video.livestream.v1.Asset.ImageAsset.uri].
            If crc32c is set, the asset can't be created if the crc32c
            value does not match with the crc32c checksum of the Cloud
            Storage object indicated by
            [VideoAsset.uri][google.cloud.video.livestream.v1.Asset.VideoAsset.uri]
            or
            [ImageAsset.uri][google.cloud.video.livestream.v1.Asset.ImageAsset.uri].
        state (google.cloud.video.live_stream_v1.types.Asset.State):
            Output only. The state of the asset resource.
        error (google.rpc.status_pb2.Status):
            Output only. Only present when ``state`` is ``ERROR``. The
            reason for the error state of the asset.
    """

    class State(proto.Enum):
        r"""State of the asset resource.

        Values:
            STATE_UNSPECIFIED (0):
                State is not specified.
            CREATING (1):
                The asset is being created.
            ACTIVE (2):
                The asset is ready for use.
            DELETING (3):
                The asset is being deleted.
            ERROR (4):
                The asset has an error.
        """
        STATE_UNSPECIFIED = 0
        CREATING = 1
        ACTIVE = 2
        DELETING = 3
        ERROR = 4

    class VideoAsset(proto.Message):
        r"""VideoAsset represents a video. The supported formats are MP4,
        MPEG-TS, and FLV. The supported video codec is H264. The
        supported audio codecs are AAC, AC3, MP2, and MP3.

        Attributes:
            uri (str):
                Cloud Storage URI of the video. The format is
                ``gs://my-bucket/my-object``.
        """

        uri: str = proto.Field(
            proto.STRING,
            number=1,
        )

    class ImageAsset(proto.Message):
        r"""Image represents an image. The supported formats are JPEG,
        PNG.

        Attributes:
            uri (str):
                Cloud Storage URI of the image. The format is
                ``gs://my-bucket/my-object``.
        """

        uri: str = proto.Field(
            proto.STRING,
            number=1,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    video: VideoAsset = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="resource",
        message=VideoAsset,
    )
    image: ImageAsset = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="resource",
        message=ImageAsset,
    )
    crc32c: str = proto.Field(
        proto.STRING,
        number=7,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=8,
        enum=State,
    )
    error: status_pb2.Status = proto.Field(
        proto.MESSAGE,
        number=9,
        message=status_pb2.Status,
    )


class Encryption(proto.Message):
    r"""Encryption settings.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        id (str):
            Required. Identifier for this set of
            encryption options. The ID must be 1-63
            characters in length. The ID must begin and end
            with a letter (regardless of case) or a number,
            but can contain dashes or underscores in
            between.
        secret_manager_key_source (google.cloud.video.live_stream_v1.types.Encryption.SecretManagerSource):
            For keys stored in Google Secret Manager.

            This field is a member of `oneof`_ ``secret_source``.
        drm_systems (google.cloud.video.live_stream_v1.types.Encryption.DrmSystems):
            Required. Configuration for DRM systems.
        aes128 (google.cloud.video.live_stream_v1.types.Encryption.Aes128Encryption):
            Configuration for HLS AES-128 encryption.

            This field is a member of `oneof`_ ``encryption_mode``.
        sample_aes (google.cloud.video.live_stream_v1.types.Encryption.SampleAesEncryption):
            Configuration for HLS SAMPLE-AES encryption.

            This field is a member of `oneof`_ ``encryption_mode``.
        mpeg_cenc (google.cloud.video.live_stream_v1.types.Encryption.MpegCommonEncryption):
            Configuration for MPEG-Dash Common Encryption
            (MPEG-CENC).

            This field is a member of `oneof`_ ``encryption_mode``.
    """

    class SecretManagerSource(proto.Message):
        r"""Configuration for secrets stored in Google Secret Manager.

        Attributes:
            secret_version (str):
                Required. The name of the Secret Version containing the
                encryption key.
                ``projects/{project}/secrets/{secret_id}/versions/{version_number}``
        """

        secret_version: str = proto.Field(
            proto.STRING,
            number=1,
        )

    class Widevine(proto.Message):
        r"""Widevine configuration."""

    class Fairplay(proto.Message):
        r"""Fairplay configuration."""

    class Playready(proto.Message):
        r"""Playready configuration."""

    class Clearkey(proto.Message):
        r"""Clearkey configuration."""

    class DrmSystems(proto.Message):
        r"""Defines configuration for DRM systems in use. If a field is
        omitted, that DRM system will be considered to be disabled.

        Attributes:
            widevine (google.cloud.video.live_stream_v1.types.Encryption.Widevine):
                Widevine configuration.
            fairplay (google.cloud.video.live_stream_v1.types.Encryption.Fairplay):
                Fairplay configuration.
            playready (google.cloud.video.live_stream_v1.types.Encryption.Playready):
                Playready configuration.
            clearkey (google.cloud.video.live_stream_v1.types.Encryption.Clearkey):
                Clearkey configuration.
        """

        widevine: "Encryption.Widevine" = proto.Field(
            proto.MESSAGE,
            number=1,
            message="Encryption.Widevine",
        )
        fairplay: "Encryption.Fairplay" = proto.Field(
            proto.MESSAGE,
            number=2,
            message="Encryption.Fairplay",
        )
        playready: "Encryption.Playready" = proto.Field(
            proto.MESSAGE,
            number=3,
            message="Encryption.Playready",
        )
        clearkey: "Encryption.Clearkey" = proto.Field(
            proto.MESSAGE,
            number=4,
            message="Encryption.Clearkey",
        )

    class Aes128Encryption(proto.Message):
        r"""Configuration for HLS AES-128 encryption."""

    class SampleAesEncryption(proto.Message):
        r"""Configuration for HLS SAMPLE-AES encryption."""

    class MpegCommonEncryption(proto.Message):
        r"""Configuration for MPEG-Dash Common Encryption (MPEG-CENC).

        Attributes:
            scheme (str):
                Required. Specify the encryption scheme, supported schemes:

                -  ``cenc`` - AES-CTR subsample
                -  ``cbcs``- AES-CBC subsample pattern
        """

        scheme: str = proto.Field(
            proto.STRING,
            number=1,
        )

    id: str = proto.Field(
        proto.STRING,
        number=1,
    )
    secret_manager_key_source: SecretManagerSource = proto.Field(
        proto.MESSAGE,
        number=7,
        oneof="secret_source",
        message=SecretManagerSource,
    )
    drm_systems: DrmSystems = proto.Field(
        proto.MESSAGE,
        number=3,
        message=DrmSystems,
    )
    aes128: Aes128Encryption = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="encryption_mode",
        message=Aes128Encryption,
    )
    sample_aes: SampleAesEncryption = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="encryption_mode",
        message=SampleAesEncryption,
    )
    mpeg_cenc: MpegCommonEncryption = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="encryption_mode",
        message=MpegCommonEncryption,
    )


class Pool(proto.Message):
    r"""Pool resource defines the configuration of Live Stream pools
    for a specific location. Currently we support only one pool
    resource per project per location. After the creation of the
    first input, a default pool is created automatically at
    "projects/{project}/locations/{location}/pools/default".

    Attributes:
        name (str):
            The resource name of the pool, in the form of:
            ``projects/{project}/locations/{location}/pools/{poolId}``.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The creation time.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The update time.
        labels (MutableMapping[str, str]):
            User-defined key/value metadata.
        network_config (google.cloud.video.live_stream_v1.types.Pool.NetworkConfig):
            Network configuration for the pool.
    """

    class NetworkConfig(proto.Message):
        r"""Defines the network configuration for the pool.

        Attributes:
            peered_network (str):
                peered_network is the network resource URL of the network
                that is peered to the service provider network. Must be of
                the format
                projects/NETWORK_PROJECT_NUMBER/global/networks/NETWORK_NAME,
                where NETWORK_PROJECT_NUMBER is the project number of the
                Cloud project that holds your VPC network and NETWORK_NAME
                is the name of your VPC network. If peered_network is
                omitted or empty, the pool will use endpoints that are
                publicly available.
        """

        peered_network: str = proto.Field(
            proto.STRING,
            number=1,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=4,
    )
    network_config: NetworkConfig = proto.Field(
        proto.MESSAGE,
        number=5,
        message=NetworkConfig,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.video.live_stream_v1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.livestream_service import (
    LivestreamServiceAsyncClient,
    LivestreamServiceClient,
)
from .types.outputs import (
    AudioStream,
    ElementaryStream,
    Manifest,
    MuxStream,
    PreprocessingConfig,
    SegmentSettings,
    SpriteSheet,
    TextStream,
    TimecodeConfig,
    VideoStream,
)
from .types.resources import (
    Asset,
    AudioFormat,
    AudioStreamProperty,
    Channel,
    Clip,
    Encryption,
    Event,
    Input,
    InputAttachment,
    InputConfig,
    InputStreamProperty,
    LogConfig,
    NormalizedCoordinate,
    NormalizedResolution,
    Pool,
    RetentionConfig,
    StaticOverlay,
    VideoFormat,
    VideoStreamProperty,
)
from .types.service import (
    ChannelOperationResponse,
    CreateAssetRequest,
    CreateChannelRequest,
    CreateClipRequest,
    CreateEventRequest,
    CreateInputRequest,
    DeleteAssetRequest,
    DeleteChannelRequest,
    DeleteClipRequest,
    DeleteEventRequest,
    DeleteInputRequest,
    GetAssetRequest,
    GetChannelRequest,
    GetClipRequest,
    GetEventRequest,
    GetInputRequest,
    GetPoolRequest,
    ListAssetsRequest,
    ListAssetsResponse,
    ListChannelsRequest,
    ListChannelsResponse,
    ListClipsRequest,
    ListClipsResponse,
    ListEventsRequest,
    ListEventsResponse,
    ListInputsRequest,
    ListInputsResponse,
    OperationMetadata,
    StartChannelRequest,
    StopChannelRequest,
    UpdateChannelRequest,
    UpdateInputRequest,
    UpdatePoolRequest,
)

__all__ = (
    "LivestreamServiceAsyncClient",
    "Asset",
    "AudioFormat",
    "AudioStream",
    "AudioStreamProperty",
    "Channel",
    "ChannelOperationResponse",
    "Clip",
    "CreateAssetRequest",
    "CreateChannelRequest",
    "CreateClipRequest",
    "CreateEventRequest",
    "CreateInputRequest",
    "DeleteAssetRequest",
    "DeleteChannelRequest",
    "DeleteClipRequest",
    "DeleteEventRequest",
    "DeleteInputRequest",
    "ElementaryStream",
    "Encryption",
    "Event",
    "GetAssetRequest",
    "GetChannelRequest",
    "GetClipRequest",
    "GetEventRequest",
    "GetInputRequest",
    "GetPoolRequest",
    "Input",
    "InputAttachment",
    "InputConfig",
    "InputStreamProperty",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListChannelsRequest",
    "ListChannelsResponse",
    "ListClipsRequest",
    "ListClipsResponse",
    "ListEventsRequest",
    "ListEventsResponse",
    "ListInputsRequest",
    "ListInputsResponse",
    "LivestreamServiceClient",
    "LogConfig",
    "Manifest",
    "MuxStream",
    "NormalizedCoordinate",
    "NormalizedResolution",
    "OperationMetadata",
    "Pool",
    "PreprocessingConfig",
    "RetentionConfig",
    "SegmentSettings",
    "SpriteSheet",
    "StartChannelRequest",
    "StaticOverlay",
    "StopChannelRequest",
    "TextStream",
    "TimecodeConfig",
    "UpdateChannelRequest",
    "UpdateInputRequest",
    "UpdatePoolRequest",
    "VideoFormat",
    "VideoStream",
    "VideoStreamProperty",
)



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import Callable, Dict, Optional, Sequence, Tuple, Union
import warnings

from google.api_core import gapic_v1, grpc_helpers, operations_v1
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport.grpc import SslCredentials  # type: ignore
from google.cloud.location import locations_pb2  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore
import grpc  # type: ignore

from google.cloud.video.live_stream_v1.types import resources, service

from .base import DEFAULT_CLIENT_INFO, LivestreamServiceTransport


class LivestreamServiceGrpcTransport(LivestreamServiceTransport):
    """gRPC backend transport for LivestreamService.

    Using Live Stream API, you can generate live streams in the
    various renditions and streaming formats. The streaming format
    include HTTP Live Streaming (HLS) and Dynamic Adaptive Streaming
    over HTTP (DASH). You can send a source stream in the various
    ways, including Real-Time Messaging Protocol (RTMP) and Secure
    Reliable Transport (SRT).

    This class defines the same methods as the primary client, so the
    primary client can load the underlying transport implementation
    and call it.

    It sends protocol buffers over the wire using gRPC (which is built on
    top of HTTP/2); the ``grpcio`` package must be installed.
    """

    _stubs: Dict[str, Callable]

    def __init__(
        self,
        *,
        host: str = "livestream.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        channel: Optional[Union[grpc.Channel, Callable[..., grpc.Channel]]] = None,
        api_mtls_endpoint: Optional[str] = None,
        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'livestream.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is ignored if a ``channel`` instance is provided.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if a ``channel`` instance is provided.
            scopes (Optional(Sequence[str])): A list of scopes. This argument is
                ignored if a ``channel`` instance is provided.
            channel (Optional[Union[grpc.Channel, Callable[..., grpc.Channel]]]):
                A ``Channel`` instance through which to make calls, or a Callable
                that constructs and returns one. If set to None, ``self.create_channel``
                is used to create the channel. If a Callable is given, it will be called
                with the same arguments as used in ``self.create_channel``.
            api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                If provided, it overrides the ``host`` argument and tries to create
                a mutual TLS channel with client SSL credentials from
                ``client_cert_source`` or application default SSL credentials.
            client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                Deprecated. A callback to provide client SSL certificate bytes and
                private key bytes, both in PEM format. It is ignored if
                ``api_mtls_endpoint`` is None.
            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
                for the grpc channel. It is ignored if a ``channel`` instance is provided.
            client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                A callback to provide client certificate bytes and private key bytes,
                both in PEM format. It is used to configure a mutual TLS channel. It is
                ignored if a ``channel`` instance or ``ssl_channel_credentials`` is provided.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.

        Raises:
          google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
              creation failed for any reason.
          google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """
        self._grpc_channel = None
        self._ssl_channel_credentials = ssl_channel_credentials
        self._stubs: Dict[str, Callable] = {}
        self._operations_client: Optional[operations_v1.OperationsClient] = None

        if api_mtls_endpoint:
            warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
        if client_cert_source:
            warnings.warn("client_cert_source is deprecated", DeprecationWarning)

        if isinstance(channel, grpc.Channel):
            # Ignore credentials if a channel was passed.
            credentials = None
            self._ignore_credentials = True
            # If a channel was explicitly provided, set it.
            self._grpc_channel = channel
            self._ssl_channel_credentials = None

        else:
            if api_mtls_endpoint:
                host = api_mtls_endpoint

                # Create SSL credentials with client_cert_source or application
                # default SSL credentials.
                if client_cert_source:
                    cert, key = client_cert_source()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )
                else:
                    self._ssl_channel_credentials = SslCredentials().ssl_credentials

            else:
                if client_cert_source_for_mtls and not ssl_channel_credentials:
                    cert, key = client_cert_source_for_mtls()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )

        # The base transport sets the host, credentials and scopes
        super().__init__(
            host=host,
            credentials=credentials,
            credentials_file=credentials_file,
            scopes=scopes,
            quota_project_id=quota_project_id,
            client_info=client_info,
            always_use_jwt_access=always_use_jwt_access,
            api_audience=api_audience,
        )

        if not self._grpc_channel:
            # initialize with the provided callable or the default channel
            channel_init = channel or type(self).create_channel
            self._grpc_channel = channel_init(
                self._host,
                # use the credentials which are saved
                credentials=self._credentials,
                # Set ``credentials_file`` to ``None`` here as
                # the credentials that we saved earlier should be used.
                credentials_file=None,
                scopes=self._scopes,
                ssl_credentials=self._ssl_channel_credentials,
                quota_project_id=quota_project_id,
                options=[
                    ("grpc.max_send_message_length", -1),
                    ("grpc.max_receive_message_length", -1),
                ],
            )

        # Wrap messages. This must be done after self._grpc_channel exists
        self._prep_wrapped_messages(client_info)

    @classmethod
    def create_channel(
        cls,
        host: str = "livestream.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        **kwargs,
    ) -> grpc.Channel:
        """Create and return a gRPC channel object.
        Args:
            host (Optional[str]): The host for the channel to use.
            credentials (Optional[~.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                service. These are only used when credentials are not specified and
                are passed to :func:`google.auth.default`.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            kwargs (Optional[dict]): Keyword arguments, which are passed to the
                channel creation.
        Returns:
            grpc.Channel: A gRPC channel object.

        Raises:
            google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """

        return grpc_helpers.create_channel(
            host,
            credentials=credentials,
            credentials_file=credentials_file,
            quota_project_id=quota_project_id,
            default_scopes=cls.AUTH_SCOPES,
            scopes=scopes,
            default_host=cls.DEFAULT_HOST,
            **kwargs,
        )

    @property
    def grpc_channel(self) -> grpc.Channel:
        """Return the channel designed to connect to this service."""
        return self._grpc_channel

    @property
    def operations_client(self) -> operations_v1.OperationsClient:
        """Create the client designed to process long-running operations.

        This property caches on the instance; repeated calls return the same
        client.
        """
        # Quick check: Only create a new client if we do not already have one.
        if self._operations_client is None:
            self._operations_client = operations_v1.OperationsClient(self.grpc_channel)

        # Return the client from cache.
        return self._operations_client

    @property
    def create_channel_(
        self,
    ) -> Callable[[service.CreateChannelRequest], operations_pb2.Operation]:
        r"""Return a callable for the create channel method over gRPC.

        Creates a channel with the provided unique ID in the
        specified region.

        Returns:
            Callable[[~.CreateChannelRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_channel_" not in self._stubs:
            self._stubs["create_channel_"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/CreateChannel",
                request_serializer=service.CreateChannelRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_channel_"]

    @property
    def list_channels(
        self,
    ) -> Callable[[service.ListChannelsRequest], service.ListChannelsResponse]:
        r"""Return a callable for the list channels method over gRPC.

        Returns a list of all channels in the specified
        region.

        Returns:
            Callable[[~.ListChannelsRequest],
                    ~.ListChannelsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_channels" not in self._stubs:
            self._stubs["list_channels"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/ListChannels",
                request_serializer=service.ListChannelsRequest.serialize,
                response_deserializer=service.ListChannelsResponse.deserialize,
            )
        return self._stubs["list_channels"]

    @property
    def get_channel(self) -> Callable[[service.GetChannelRequest], resources.Channel]:
        r"""Return a callable for the get channel method over gRPC.

        Returns the specified channel.

        Returns:
            Callable[[~.GetChannelRequest],
                    ~.Channel]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_channel" not in self._stubs:
            self._stubs["get_channel"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/GetChannel",
                request_serializer=service.GetChannelRequest.serialize,
                response_deserializer=resources.Channel.deserialize,
            )
        return self._stubs["get_channel"]

    @property
    def delete_channel(
        self,
    ) -> Callable[[service.DeleteChannelRequest], operations_pb2.Operation]:
        r"""Return a callable for the delete channel method over gRPC.

        Deletes the specified channel.

        Returns:
            Callable[[~.DeleteChannelRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_channel" not in self._stubs:
            self._stubs["delete_channel"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/DeleteChannel",
                request_serializer=service.DeleteChannelRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_channel"]

    @property
    def update_channel(
        self,
    ) -> Callable[[service.UpdateChannelRequest], operations_pb2.Operation]:
        r"""Return a callable for the update channel method over gRPC.

        Updates the specified channel.

        Returns:
            Callable[[~.UpdateChannelRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_channel" not in self._stubs:
            self._stubs["update_channel"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/UpdateChannel",
                request_serializer=service.UpdateChannelRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_channel"]

    @property
    def start_channel(
        self,
    ) -> Callable[[service.StartChannelRequest], operations_pb2.Operation]:
        r"""Return a callable for the start channel method over gRPC.

        Starts the specified channel. Part of the video
        pipeline will be created only when the StartChannel
        request is received by the server.

        Returns:
            Callable[[~.StartChannelRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "start_channel" not in self._stubs:
            self._stubs["start_channel"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/StartChannel",
                request_serializer=service.StartChannelRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["start_channel"]

    @property
    def stop_channel(
        self,
    ) -> Callable[[service.StopChannelRequest], operations_pb2.Operation]:
        r"""Return a callable for the stop channel method over gRPC.

        Stops the specified channel. Part of the video
        pipeline will be released when the StopChannel request
        is received by the server.

        Returns:
            Callable[[~.StopChannelRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "stop_channel" not in self._stubs:
            self._stubs["stop_channel"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/StopChannel",
                request_serializer=service.StopChannelRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["stop_channel"]

    @property
    def create_input(
        self,
    ) -> Callable[[service.CreateInputRequest], operations_pb2.Operation]:
        r"""Return a callable for the create input method over gRPC.

        Creates an input with the provided unique ID in the
        specified region.

        Returns:
            Callable[[~.CreateInputRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_input" not in self._stubs:
            self._stubs["create_input"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/CreateInput",
                request_serializer=service.CreateInputRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_input"]

    @property
    def list_inputs(
        self,
    ) -> Callable[[service.ListInputsRequest], service.ListInputsResponse]:
        r"""Return a callable for the list inputs method over gRPC.

        Returns a list of all inputs in the specified region.

        Returns:
            Callable[[~.ListInputsRequest],
                    ~.ListInputsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_inputs" not in self._stubs:
            self._stubs["list_inputs"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/ListInputs",
                request_serializer=service.ListInputsRequest.serialize,
                response_deserializer=service.ListInputsResponse.deserialize,
            )
        return self._stubs["list_inputs"]

    @property
    def get_input(self) -> Callable[[service.GetInputRequest], resources.Input]:
        r"""Return a callable for the get input method over gRPC.

        Returns the specified input.

        Returns:
            Callable[[~.GetInputRequest],
                    ~.Input]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_input" not in self._stubs:
            self._stubs["get_input"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/GetInput",
                request_serializer=service.GetInputRequest.serialize,
                response_deserializer=resources.Input.deserialize,
            )
        return self._stubs["get_input"]

    @property
    def delete_input(
        self,
    ) -> Callable[[service.DeleteInputRequest], operations_pb2.Operation]:
        r"""Return a callable for the delete input method over gRPC.

        Deletes the specified input.

        Returns:
            Callable[[~.DeleteInputRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_input" not in self._stubs:
            self._stubs["delete_input"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/DeleteInput",
                request_serializer=service.DeleteInputRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_input"]

    @property
    def update_input(
        self,
    ) -> Callable[[service.UpdateInputRequest], operations_pb2.Operation]:
        r"""Return a callable for the update input method over gRPC.

        Updates the specified input.

        Returns:
            Callable[[~.UpdateInputRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_input" not in self._stubs:
            self._stubs["update_input"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/UpdateInput",
                request_serializer=service.UpdateInputRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_input"]

    @property
    def create_event(self) -> Callable[[service.CreateEventRequest], resources.Event]:
        r"""Return a callable for the create event method over gRPC.

        Creates an event with the provided unique ID in the
        specified channel.

        Returns:
            Callable[[~.CreateEventRequest],
                    ~.Event]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_event" not in self._stubs:
            self._stubs["create_event"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/CreateEvent",
                request_serializer=service.CreateEventRequest.serialize,
                response_deserializer=resources.Event.deserialize,
            )
        return self._stubs["create_event"]

    @property
    def list_events(
        self,
    ) -> Callable[[service.ListEventsRequest], service.ListEventsResponse]:
        r"""Return a callable for the list events method over gRPC.

        Returns a list of all events in the specified
        channel.

        Returns:
            Callable[[~.ListEventsRequest],
                    ~.ListEventsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_events" not in self._stubs:
            self._stubs["list_events"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/ListEvents",
                request_serializer=service.ListEventsRequest.serialize,
                response_deserializer=service.ListEventsResponse.deserialize,
            )
        return self._stubs["list_events"]

    @property
    def get_event(self) -> Callable[[service.GetEventRequest], resources.Event]:
        r"""Return a callable for the get event method over gRPC.

        Returns the specified event.

        Returns:
            Callable[[~.GetEventRequest],
                    ~.Event]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_event" not in self._stubs:
            self._stubs["get_event"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/GetEvent",
                request_serializer=service.GetEventRequest.serialize,
                response_deserializer=resources.Event.deserialize,
            )
        return self._stubs["get_event"]

    @property
    def delete_event(self) -> Callable[[service.DeleteEventRequest], empty_pb2.Empty]:
        r"""Return a callable for the delete event method over gRPC.

        Deletes the specified event.

        Returns:
            Callable[[~.DeleteEventRequest],
                    ~.Empty]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_event" not in self._stubs:
            self._stubs["delete_event"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/DeleteEvent",
                request_serializer=service.DeleteEventRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_event"]

    @property
    def list_clips(
        self,
    ) -> Callable[[service.ListClipsRequest], service.ListClipsResponse]:
        r"""Return a callable for the list clips method over gRPC.

        Returns a list of all clips in the specified channel.

        Returns:
            Callable[[~.ListClipsRequest],
                    ~.ListClipsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_clips" not in self._stubs:
            self._stubs["list_clips"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/ListClips",
                request_serializer=service.ListClipsRequest.serialize,
                response_deserializer=service.ListClipsResponse.deserialize,
            )
        return self._stubs["list_clips"]

    @property
    def get_clip(self) -> Callable[[service.GetClipRequest], resources.Clip]:
        r"""Return a callable for the get clip method over gRPC.

        Returns the specified clip.

        Returns:
            Callable[[~.GetClipRequest],
                    ~.Clip]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_clip" not in self._stubs:
            self._stubs["get_clip"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/GetClip",
                request_serializer=service.GetClipRequest.serialize,
                response_deserializer=resources.Clip.deserialize,
            )
        return self._stubs["get_clip"]

    @property
    def create_clip(
        self,
    ) -> Callable[[service.CreateClipRequest], operations_pb2.Operation]:
        r"""Return a callable for the create clip method over gRPC.

        Creates a clip with the provided clip ID in the
        specified channel.

        Returns:
            Callable[[~.CreateClipRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_clip" not in self._stubs:
            self._stubs["create_clip"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/CreateClip",
                request_serializer=service.CreateClipRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_clip"]

    @property
    def delete_clip(
        self,
    ) -> Callable[[service.DeleteClipRequest], operations_pb2.Operation]:
        r"""Return a callable for the delete clip method over gRPC.

        Deletes the specified clip job resource. This method
        only deletes the clip job and does not delete the VOD
        clip stored in the GCS.

        Returns:
            Callable[[~.DeleteClipRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_clip" not in self._stubs:
            self._stubs["delete_clip"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/DeleteClip",
                request_serializer=service.DeleteClipRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_clip"]

    @property
    def create_asset(
        self,
    ) -> Callable[[service.CreateAssetRequest], operations_pb2.Operation]:
        r"""Return a callable for the create asset method over gRPC.

        Creates a Asset with the provided unique ID in the
        specified region.

        Returns:
            Callable[[~.CreateAssetRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_asset" not in self._stubs:
            self._stubs["create_asset"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/CreateAsset",
                request_serializer=service.CreateAssetRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_asset"]

    @property
    def delete_asset(
        self,
    ) -> Callable[[service.DeleteAssetRequest], operations_pb2.Operation]:
        r"""Return a callable for the delete asset method over gRPC.

        Deletes the specified asset if it is not used.

        Returns:
            Callable[[~.DeleteAssetRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_asset" not in self._stubs:
            self._stubs["delete_asset"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/DeleteAsset",
                request_serializer=service.DeleteAssetRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_asset"]

    @property
    def get_asset(self) -> Callable[[service.GetAssetRequest], resources.Asset]:
        r"""Return a callable for the get asset method over gRPC.

        Returns the specified asset.

        Returns:
            Callable[[~.GetAssetRequest],
                    ~.Asset]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_asset" not in self._stubs:
            self._stubs["get_asset"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/GetAsset",
                request_serializer=service.GetAssetRequest.serialize,
                response_deserializer=resources.Asset.deserialize,
            )
        return self._stubs["get_asset"]

    @property
    def list_assets(
        self,
    ) -> Callable[[service.ListAssetsRequest], service.ListAssetsResponse]:
        r"""Return a callable for the list assets method over gRPC.

        Returns a list of all assets in the specified region.

        Returns:
            Callable[[~.ListAssetsRequest],
                    ~.ListAssetsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_assets" not in self._stubs:
            self._stubs["list_assets"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/ListAssets",
                request_serializer=service.ListAssetsRequest.serialize,
                response_deserializer=service.ListAssetsResponse.deserialize,
            )
        return self._stubs["list_assets"]

    @property
    def get_pool(self) -> Callable[[service.GetPoolRequest], resources.Pool]:
        r"""Return a callable for the get pool method over gRPC.

        Returns the specified pool.

        Returns:
            Callable[[~.GetPoolRequest],
                    ~.Pool]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_pool" not in self._stubs:
            self._stubs["get_pool"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/GetPool",
                request_serializer=service.GetPoolRequest.serialize,
                response_deserializer=resources.Pool.deserialize,
            )
        return self._stubs["get_pool"]

    @property
    def update_pool(
        self,
    ) -> Callable[[service.UpdatePoolRequest], operations_pb2.Operation]:
        r"""Return a callable for the update pool method over gRPC.

        Updates the specified pool.

        Returns:
            Callable[[~.UpdatePoolRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_pool" not in self._stubs:
            self._stubs["update_pool"] = self.grpc_channel.unary_unary(
                "/google.cloud.video.livestream.v1.LivestreamService/UpdatePool",
                request_serializer=service.UpdatePoolRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_pool"]

    def close(self):
        self.grpc_channel.close()

    @property
    def delete_operation(
        self,
    ) -> Callable[[operations_pb2.DeleteOperationRequest], None]:
        r"""Return a callable for the delete_operation method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_operation" not in self._stubs:
            self._stubs["delete_operation"] = self.grpc_channel.unary_unary(
                "/google.longrunning.Operations/DeleteOperation",
                request_serializer=operations_pb2.DeleteOperationRequest.SerializeToString,
                response_deserializer=None,
            )
        return self._stubs["delete_operation"]

    @property
    def cancel_operation(
        self,
    ) -> Callable[[operations_pb2.CancelOperationRequest], None]:
        r"""Return a callable for the cancel_operation method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "cancel_operation" not in self._stubs:
            self._stubs["cancel_operation"] = self.grpc_channel.unary_unary(
                "/google.longrunning.Operations/CancelOperation",
                request_serializer=operations_pb2.CancelOperationRequest.SerializeToString,
                response_deserializer=None,
            )
        return self._stubs["cancel_operation"]

    @property
    def get_operation(
        self,
    ) -> Callable[[operations_pb2.GetOperationRequest], operations_pb2.Operation]:
        r"""Return a callable for the get_operation method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_operation" not in self._stubs:
            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
                "/google.longrunning.Operations/GetOperation",
                request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["get_operation"]

    @property
    def list_operations(
        self,
    ) -> Callable[
        [operations_pb2.ListOperationsRequest], operations_pb2.ListOperationsResponse
    ]:
        r"""Return a callable for the list_operations method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_operations" not in self._stubs:
            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
                "/google.longrunning.Operations/ListOperations",
                request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
                response_deserializer=operations_pb2.ListOperationsResponse.FromString,
            )
        return self._stubs["list_operations"]

    @property
    def list_locations(
        self,
    ) -> Callable[
        [locations_pb2.ListLocationsRequest], locations_pb2.ListLocationsResponse
    ]:
        r"""Return a callable for the list locations method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_locations" not in self._stubs:
            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
                "/google.cloud.location.Locations/ListLocations",
                request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
                response_deserializer=locations_pb2.ListLocationsResponse.FromString,
            )
        return self._stubs["list_locations"]

    @property
    def get_location(
        self,
    ) -> Callable[[locations_pb2.GetLocationRequest], locations_pb2.Location]:
        r"""Return a callable for the list locations method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_location" not in self._stubs:
            self._stubs["get_location"] = self.grpc_channel.unary_unary(
                "/google.cloud.location.Locations/GetLocation",
                request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
                response_deserializer=locations_pb2.Location.FromString,
            )
        return self._stubs["get_location"]

    @property
    def kind(self) -> str:
        return "grpc"


__all__ = ("LivestreamServiceGrpcTransport",)



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.type import datetime_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.video.livestream.v1",
    manifest={
        "ElementaryStream",
        "MuxStream",
        "Manifest",
        "SpriteSheet",
        "PreprocessingConfig",
        "VideoStream",
        "AudioStream",
        "TextStream",
        "SegmentSettings",
        "TimecodeConfig",
    },
)


class ElementaryStream(proto.Message):
    r"""Encoding of an input element such as an audio, video, or text
    track. Elementary streams must be packaged before mapping and
    sharing between different output formats.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        key (str):
            A unique key for this elementary stream. The
            key must be 1-63 characters in length. The key
            must begin and end with a letter (regardless of
            case) or a number, but can contain dashes or
            underscores in between.
        video_stream (google.cloud.video.live_stream_v1.types.VideoStream):
            Encoding of a video stream.

            This field is a member of `oneof`_ ``elementary_stream``.
        audio_stream (google.cloud.video.live_stream_v1.types.AudioStream):
            Encoding of an audio stream.

            This field is a member of `oneof`_ ``elementary_stream``.
        text_stream (google.cloud.video.live_stream_v1.types.TextStream):
            Encoding of a text stream. For example,
            closed captions or subtitles.

            This field is a member of `oneof`_ ``elementary_stream``.
    """

    key: str = proto.Field(
        proto.STRING,
        number=4,
    )
    video_stream: "VideoStream" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="elementary_stream",
        message="VideoStream",
    )
    audio_stream: "AudioStream" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="elementary_stream",
        message="AudioStream",
    )
    text_stream: "TextStream" = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="elementary_stream",
        message="TextStream",
    )


class MuxStream(proto.Message):
    r"""Multiplexing settings for output stream.

    Attributes:
        key (str):
            A unique key for this multiplexed stream. The
            key must be 1-63 characters in length. The key
            must begin and end with a letter (regardless of
            case) or a number, but can contain dashes or
            underscores in between.
        container (str):
            The container format. The default is ``fmp4``.

            Supported container formats:

            -  ``fmp4`` - the corresponding file extension is ``.m4s``
            -  ``ts`` - the corresponding file extension is ``.ts``
        elementary_streams (MutableSequence[str]):
            List of ``ElementaryStream``
            [key][google.cloud.video.livestream.v1.ElementaryStream.key]s
            multiplexed in this stream.

            -  For ``fmp4`` container, must contain either one video or
               one audio stream.
            -  For ``ts`` container, must contain exactly one audio
               stream and up to one video stream.
        segment_settings (google.cloud.video.live_stream_v1.types.SegmentSettings):
            Segment settings for ``fmp4`` and ``ts``.
        encryption_id (str):
            Identifier of the encryption configuration to
            use. If omitted, output will be unencrypted.
    """

    key: str = proto.Field(
        proto.STRING,
        number=1,
    )
    container: str = proto.Field(
        proto.STRING,
        number=3,
    )
    elementary_streams: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )
    segment_settings: "SegmentSettings" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="SegmentSettings",
    )
    encryption_id: str = proto.Field(
        proto.STRING,
        number=6,
    )


class Manifest(proto.Message):
    r"""Manifest configuration.

    Attributes:
        file_name (str):
            The name of the generated file. The default is ``manifest``
            with the extension suffix corresponding to the ``Manifest``
            [type][google.cloud.video.livestream.v1.Manifest.type]. If
            multiple manifests are added to the channel, each must have
            a unique file name.
        type_ (google.cloud.video.live_stream_v1.types.Manifest.ManifestType):
            Required. Type of the manifest, can be ``HLS`` or ``DASH``.
        mux_streams (MutableSequence[str]):
            Required. List of ``MuxStream``
            [key][google.cloud.video.livestream.v1.MuxStream.key]s that
            should appear in this manifest.

            -  For HLS, either ``fmp4`` or ``ts`` mux streams can be
               specified but not mixed.
            -  For DASH, only ``fmp4`` mux streams can be specified.
        max_segment_count (int):
            Maximum number of segments that this manifest
            holds. Once the manifest reaches this maximum
            number of segments, whenever a new segment is
            added to the manifest, the oldest segment will
            be removed from the manifest. The minimum value
            is 3 and the default value is 5.
        segment_keep_duration (google.protobuf.duration_pb2.Duration):
            How long to keep a segment on the output Google Cloud
            Storage bucket after it is removed from the manifest. This
            field should be large enough to cover the manifest
            propagation delay. Otherwise, a player could receive 404
            errors while accessing segments which are listed in the
            manifest that the player has, but were already deleted from
            the output Google Cloud Storage bucket. Default value is
            ``60s``.

            If both segment_keep_duration and
            [RetentionConfig.retention_window_duration][google.cloud.video.livestream.v1.RetentionConfig.retention_window_duration]
            are set,
            [RetentionConfig.retention_window_duration][google.cloud.video.livestream.v1.RetentionConfig.retention_window_duration]
            is used and segment_keep_duration is ignored.
        use_timecode_as_timeline (bool):
            Whether to use the timecode, as specified in timecode
            config, when setting:

            -  ``availabilityStartTime`` attribute in DASH manifests.
            -  ``#EXT-X-PROGRAM-DATE-TIME`` tag in HLS manifests.

            If false, ignore the input timecode and use the time from
            system clock when the manifest is first generated. This is
            the default behavior.
        key (str):
            Optional. A unique key for this manifest.
    """

    class ManifestType(proto.Enum):
        r"""The manifest type can be either ``HLS`` or ``DASH``.

        Values:
            MANIFEST_TYPE_UNSPECIFIED (0):
                The manifest type is not specified.
            HLS (1):
                Create an ``HLS`` manifest. The corresponding file extension
                is ``.m3u8``.
            DASH (2):
                Create a ``DASH`` manifest. The corresponding file extension
                is ``.mpd``.
        """
        MANIFEST_TYPE_UNSPECIFIED = 0
        HLS = 1
        DASH = 2

    file_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    type_: ManifestType = proto.Field(
        proto.ENUM,
        number=2,
        enum=ManifestType,
    )
    mux_streams: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    max_segment_count: int = proto.Field(
        proto.INT32,
        number=4,
    )
    segment_keep_duration: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=5,
        message=duration_pb2.Duration,
    )
    use_timecode_as_timeline: bool = proto.Field(
        proto.BOOL,
        number=6,
    )
    key: str = proto.Field(
        proto.STRING,
        number=7,
    )


class SpriteSheet(proto.Message):
    r"""Sprite sheet configuration.

    Attributes:
        format_ (str):
            Format type. The default is ``jpeg``.

            Supported formats:

            -  ``jpeg``
        file_prefix (str):
            Required. File name prefix for the generated sprite sheets.
            If multiple sprite sheets are added to the channel, each
            must have a unique file prefix. Each sprite sheet has an
            incremental 10-digit zero-padded suffix starting from 0
            before the extension, such as
            ``sprite_sheet0000000123.jpeg``.
        sprite_width_pixels (int):
            Required. The width of the sprite in pixels.
            Must be an even integer.
        sprite_height_pixels (int):
            Required. The height of the sprite in pixels.
            Must be an even integer.
        column_count (int):
            The maximum number of sprites per row in a sprite sheet.
            Valid range is [1, 10] and the default value is 1.
        row_count (int):
            The maximum number of rows per sprite sheet. When the sprite
            sheet is full, a new sprite sheet is created. Valid range is
            [1, 10] and the default value is 1.
        interval (google.protobuf.duration_pb2.Duration):
            Create sprites at regular intervals. Valid range is [1
            second, 1 hour] and the default value is ``10s``.
        quality (int):
            The quality of the generated sprite sheet.
            Enter a value between 1 and 100, where 1 is the
            lowest quality and 100 is the highest quality.
            The default is 100. A high quality value
            corresponds to a low image data compression
            ratio.
    """

    format_: str = proto.Field(
        proto.STRING,
        number=1,
    )
    file_prefix: str = proto.Field(
        proto.STRING,
        number=2,
    )
    sprite_width_pixels: int = proto.Field(
        proto.INT32,
        number=3,
    )
    sprite_height_pixels: int = proto.Field(
        proto.INT32,
        number=4,
    )
    column_count: int = proto.Field(
        proto.INT32,
        number=5,
    )
    row_count: int = proto.Field(
        proto.INT32,
        number=6,
    )
    interval: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=7,
        message=duration_pb2.Duration,
    )
    quality: int = proto.Field(
        proto.INT32,
        number=8,
    )


class PreprocessingConfig(proto.Message):
    r"""Preprocessing configurations.

    Attributes:
        audio (google.cloud.video.live_stream_v1.types.PreprocessingConfig.Audio):
            Audio preprocessing configuration.
        crop (google.cloud.video.live_stream_v1.types.PreprocessingConfig.Crop):
            Specify the video cropping configuration.
        pad (google.cloud.video.live_stream_v1.types.PreprocessingConfig.Pad):
            Specify the video pad filter configuration.
    """

    class Audio(proto.Message):
        r"""Audio preprocessing configuration.

        Attributes:
            lufs (float):
                Specify audio loudness normalization in
                loudness units relative to full scale (LUFS).
                Enter a value between -24 and 0 according to the
                following:

                - -24 is the Advanced Television Systems
                  Committee (ATSC A/85)
                - -23 is the EU R128 broadcast standard
                - -19 is the prior standard for online mono
                  audio
                - -18 is the ReplayGain standard
                - -16 is the prior standard for stereo audio
                - -14 is the new online audio standard
                  recommended by Spotify, as well as Amazon Echo
                - 0 disables normalization. The default is 0.
        """

        lufs: float = proto.Field(
            proto.DOUBLE,
            number=1,
        )

    class Crop(proto.Message):
        r"""Video cropping configuration for the input video. The cropped
        input video is scaled to match the output resolution.

        Attributes:
            top_pixels (int):
                The number of pixels to crop from the top.
                The default is 0.
            bottom_pixels (int):
                The number of pixels to crop from the bottom.
                The default is 0.
            left_pixels (int):
                The number of pixels to crop from the left.
                The default is 0.
            right_pixels (int):
                The number of pixels to crop from the right.
                The default is 0.
        """

        top_pixels: int = proto.Field(
            proto.INT32,
            number=1,
        )
        bottom_pixels: int = proto.Field(
            proto.INT32,
            number=2,
        )
        left_pixels: int = proto.Field(
            proto.INT32,
            number=3,
        )
        right_pixels: int = proto.Field(
            proto.INT32,
            number=4,
        )

    class Pad(proto.Message):
        r"""Pad filter configuration for the input video. The padded
        input video is scaled after padding with black to match the
        output resolution.

        Attributes:
            top_pixels (int):
                The number of pixels to add to the top. The
                default is 0.
            bottom_pixels (int):
                The number of pixels to add to the bottom.
                The default is 0.
            left_pixels (int):
                The number of pixels to add to the left. The
                default is 0.
            right_pixels (int):
                The number of pixels to add to the right. The
                default is 0.
        """

        top_pixels: int = proto.Field(
            proto.INT32,
            number=1,
        )
        bottom_pixels: int = proto.Field(
            proto.INT32,
            number=2,
        )
        left_pixels: int = proto.Field(
            proto.INT32,
            number=3,
        )
        right_pixels: int = proto.Field(
            proto.INT32,
            number=4,
        )

    audio: Audio = proto.Field(
        proto.MESSAGE,
        number=1,
        message=Audio,
    )
    crop: Crop = proto.Field(
        proto.MESSAGE,
        number=2,
        message=Crop,
    )
    pad: Pad = proto.Field(
        proto.MESSAGE,
        number=3,
        message=Pad,
    )


class VideoStream(proto.Message):
    r"""Video stream resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        h264 (google.cloud.video.live_stream_v1.types.VideoStream.H264CodecSettings):
            H264 codec settings.

            This field is a member of `oneof`_ ``codec_settings``.
    """

    class H264CodecSettings(proto.Message):
        r"""H264 codec settings.

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            width_pixels (int):
                Required. The width of the video in pixels. Must be an even
                integer. Valid range is [320, 1920].
            height_pixels (int):
                Required. The height of the video in pixels. Must be an even
                integer. Valid range is [180, 1080].
            frame_rate (float):
                Required. The target video frame rate in frames per second
                (FPS). Must be less than or equal to 60. Will default to the
                input frame rate if larger than the input frame rate. The
                API will generate an output FPS that is divisible by the
                input FPS, and smaller or equal to the target FPS. See
                `Calculating frame
                rate <https://cloud.google.com/transcoder/docs/concepts/frame-rate>`__
                for more information.
            bitrate_bps (int):
                Required. The video bitrate in bits per
                second. Minimum value is 10,000.

                - For SD resolution (< 720p), must be <=
                  3,000,000 (3 Mbps).
                - For HD resolution (<= 1080p), must be <=
                  15,000,000 (15 Mbps).
            allow_open_gop (bool):
                Specifies whether an open Group of Pictures (GOP) structure
                should be allowed or not. The default is ``false``.
            gop_frame_count (int):
                Select the GOP size based on the specified frame count. If
                GOP frame count is set instead of GOP duration, GOP duration
                will be calculated by ``gopFrameCount``/``frameRate``. The
                calculated GOP duration must satisfy the limitations on
                ``gopDuration`` as well. Valid range is [60, 600].

                This field is a member of `oneof`_ ``gop_mode``.
            gop_duration (google.protobuf.duration_pb2.Duration):
                Select the GOP size based on the specified duration. The
                default is ``2s``. Note that ``gopDuration`` must be less
                than or equal to
                [segment_duration][google.cloud.video.livestream.v1.SegmentSettings.segment_duration],
                and
                [segment_duration][google.cloud.video.livestream.v1.SegmentSettings.segment_duration]
                must be divisible by ``gopDuration``. Valid range is [2s,
                20s].

                All video streams in the same channel must have the same GOP
                size.

                This field is a member of `oneof`_ ``gop_mode``.
            vbv_size_bits (int):
                Size of the Video Buffering Verifier (VBV) buffer in bits.
                Must be greater than zero. The default is equal to
                [bitrate_bps][google.cloud.video.livestream.v1.VideoStream.H264CodecSettings.bitrate_bps].
            vbv_fullness_bits (int):
                Initial fullness of the Video Buffering Verifier (VBV)
                buffer in bits. Must be greater than zero. The default is
                equal to 90% of
                [vbv_size_bits][google.cloud.video.livestream.v1.VideoStream.H264CodecSettings.vbv_size_bits].
            entropy_coder (str):
                The entropy coder to use. The default is ``cabac``.

                Supported entropy coders:

                -  ``cavlc``
                -  ``cabac``
            b_pyramid (bool):
                Allow B-pyramid for reference frame selection. This may not
                be supported on all decoders. The default is ``false``.
            b_frame_count (int):
                The number of consecutive B-frames. Must be greater than or
                equal to zero. Must be less than
                [gop_frame_count][google.cloud.video.livestream.v1.VideoStream.H264CodecSettings.gop_frame_count]
                if set. The default is 0.
            aq_strength (float):
                Specify the intensity of the adaptive
                quantizer (AQ). Must be between 0 and 1, where 0
                disables the quantizer and 1 maximizes the
                quantizer. A higher value equals a lower bitrate
                but smoother image. The default is 0.
            profile (str):
                Enforces the specified codec profile. The following profiles
                are supported:

                -  ``baseline``
                -  ``main`` (default)
                -  ``high``

                The available options are `FFmpeg-compatible Profile
                Options <https://trac.ffmpeg.org/wiki/Encode/H.264#Profile>`__.
                Note that certain values for this field may cause the
                transcoder to override other fields you set in the
                [H264CodecSettings][google.cloud.video.livestream.v1.VideoStream.H264CodecSettings]
                message.
            tune (str):
                Enforces the specified codec tune. The available options are
                `FFmpeg-compatible Encode
                Options <https://trac.ffmpeg.org/wiki/Encode/H.264#Tune>`__
                Note that certain values for this field may cause the
                transcoder to override other fields you set in the
                [H264CodecSettings][google.cloud.video.livestream.v1.VideoStream.H264CodecSettings]
                message.
        """

        width_pixels: int = proto.Field(
            proto.INT32,
            number=1,
        )
        height_pixels: int = proto.Field(
            proto.INT32,
            number=2,
        )
        frame_rate: float = proto.Field(
            proto.DOUBLE,
            number=3,
        )
        bitrate_bps: int = proto.Field(
            proto.INT32,
            number=4,
        )
        allow_open_gop: bool = proto.Field(
            proto.BOOL,
            number=6,
        )
        gop_frame_count: int = proto.Field(
            proto.INT32,
            number=7,
            oneof="gop_mode",
        )
        gop_duration: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=8,
            oneof="gop_mode",
            message=duration_pb2.Duration,
        )
        vbv_size_bits: int = proto.Field(
            proto.INT32,
            number=9,
        )
        vbv_fullness_bits: int = proto.Field(
            proto.INT32,
            number=10,
        )
        entropy_coder: str = proto.Field(
            proto.STRING,
            number=11,
        )
        b_pyramid: bool = proto.Field(
            proto.BOOL,
            number=12,
        )
        b_frame_count: int = proto.Field(
            proto.INT32,
            number=13,
        )
        aq_strength: float = proto.Field(
            proto.DOUBLE,
            number=14,
        )
        profile: str = proto.Field(
            proto.STRING,
            number=15,
        )
        tune: str = proto.Field(
            proto.STRING,
            number=16,
        )

    h264: H264CodecSettings = proto.Field(
        proto.MESSAGE,
        number=20,
        oneof="codec_settings",
        message=H264CodecSettings,
    )


class AudioStream(proto.Message):
    r"""Audio stream resource.

    Attributes:
        transmux (bool):
            Specifies whether pass through (transmuxing) is enabled or
            not. If set to ``true``, the rest of the settings, other
            than ``mapping``, will be ignored. The default is ``false``.
        codec (str):
            The codec for this audio stream. The default is ``aac``.

            Supported audio codecs:

            -  ``aac``
        bitrate_bps (int):
            Required. Audio bitrate in bits per second.
            Must be between 1 and 10,000,000.
        channel_count (int):
            Number of audio channels. Must be between 1
            and 6. The default is 2.
        channel_layout (MutableSequence[str]):
            A list of channel names specifying layout of the audio
            channels. This only affects the metadata embedded in the
            container headers, if supported by the specified format. The
            default is ``[fl, fr]``.

            Supported channel names:

            -  ``fl`` - Front left channel
            -  ``fr`` - Front right channel
            -  ``sl`` - Side left channel
            -  ``sr`` - Side right channel
            -  ``fc`` - Front center channel
            -  ``lfe`` - Low frequency
        mapping_ (MutableSequence[google.cloud.video.live_stream_v1.types.AudioStream.AudioMapping]):
            The mapping for the input streams and audio
            channels.
        sample_rate_hertz (int):
            The audio sample rate in Hertz. The default
            is 48000 Hertz.
    """

    class AudioMapping(proto.Message):
        r"""The mapping for the input streams and audio channels.

        Attributes:
            input_key (str):
                Required. The ``Channel``
                [InputAttachment.key][google.cloud.video.livestream.v1.InputAttachment.key]
                that identifies the input that this audio mapping applies
                to. If an active input doesn't have an audio mapping, the
                primary audio track in the input stream will be selected.
            input_track (int):
                Required. The zero-based index of the track in the input
                stream. All
                [mapping][google.cloud.video.livestream.v1.AudioStream.mapping]s
                in the same
                [AudioStream][google.cloud.video.livestream.v1.AudioStream]
                must have the same input track.
            input_channel (int):
                Required. The zero-based index of the channel
                in the input stream.
            output_channel (int):
                Required. The zero-based index of the channel in the output
                audio stream. Must be consistent with the
                [input_channel][google.cloud.video.livestream.v1.AudioStream.AudioMapping.input_channel].
            gain_db (float):
                Audio volume control in dB. Negative values
                decrease volume, positive values increase. The
                default is 0.
        """

        input_key: str = proto.Field(
            proto.STRING,
            number=6,
        )
        input_track: int = proto.Field(
            proto.INT32,
            number=2,
        )
        input_channel: int = proto.Field(
            proto.INT32,
            number=3,
        )
        output_channel: int = proto.Field(
            proto.INT32,
            number=4,
        )
        gain_db: float = proto.Field(
            proto.DOUBLE,
            number=5,
        )

    transmux: bool = proto.Field(
        proto.BOOL,
        number=8,
    )
    codec: str = proto.Field(
        proto.STRING,
        number=1,
    )
    bitrate_bps: int = proto.Field(
        proto.INT32,
        number=2,
    )
    channel_count: int = proto.Field(
        proto.INT32,
        number=3,
    )
    channel_layout: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )
    mapping_: MutableSequence[AudioMapping] = proto.RepeatedField(
        proto.MESSAGE,
        number=5,
        message=AudioMapping,
    )
    sample_rate_hertz: int = proto.Field(
        proto.INT32,
        number=6,
    )


class TextStream(proto.Message):
    r"""Encoding of a text stream. For example, closed captions or
    subtitles.

    Attributes:
        codec (str):
            Required. The codec for this text stream.

            Supported text codecs:

            -  ``cea608``
            -  ``cea708``
    """

    codec: str = proto.Field(
        proto.STRING,
        number=1,
    )


class SegmentSettings(proto.Message):
    r"""Segment settings for ``fmp4`` and ``ts``.

    Attributes:
        segment_duration (google.protobuf.duration_pb2.Duration):
            Duration of the segments in seconds. The default is ``6s``.
            Note that ``segmentDuration`` must be greater than or equal
            to
            [gop_duration][google.cloud.video.livestream.v1.VideoStream.H264CodecSettings.gop_duration],
            and ``segmentDuration`` must be divisible by
            [gop_duration][google.cloud.video.livestream.v1.VideoStream.H264CodecSettings.gop_duration].
            Valid range is [2s, 20s].

            All
            [mux_streams][google.cloud.video.livestream.v1.Manifest.mux_streams]
            in the same manifest must have the same segment duration.
    """

    segment_duration: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=1,
        message=duration_pb2.Duration,
    )


class TimecodeConfig(proto.Message):
    r"""Timecode configuration.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        source (google.cloud.video.live_stream_v1.types.TimecodeConfig.TimecodeSource):
            The source of the timecode that will later be
            used in outputs/manifests. It determines the
            initial timecode/timestamp (first frame) of
            output streams.
        utc_offset (google.protobuf.duration_pb2.Duration):
            UTC offset. Must be whole seconds, between
            -18 hours and +18 hours.

            This field is a member of `oneof`_ ``time_offset``.
        time_zone (google.type.datetime_pb2.TimeZone):
            Time zone e.g. "America/Los_Angeles".

            This field is a member of `oneof`_ ``time_offset``.
    """

    class TimecodeSource(proto.Enum):
        r"""The source of timecode.

        Values:
            TIMECODE_SOURCE_UNSPECIFIED (0):
                The timecode source is not specified.
            MEDIA_TIMESTAMP (1):
                Use input media timestamp.
            EMBEDDED_TIMECODE (2):
                Use input embedded timecode e.g. picture
                timing SEI message.
        """
        TIMECODE_SOURCE_UNSPECIFIED = 0
        MEDIA_TIMESTAMP = 1
        EMBEDDED_TIMECODE = 2

    source: TimecodeSource = proto.Field(
        proto.ENUM,
        number=1,
        enum=TimecodeSource,
    )
    utc_offset: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="time_offset",
        message=duration_pb2.Duration,
    )
    time_zone: datetime_pb2.TimeZone = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="time_offset",
        message=datetime_pb2.TimeZone,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
